@@ -1,12 +1,7 @@
-use strict 'vars', 'subs';                                                                                                         # Moved to stop Perl::Critic carping when Dist::Zilla adds
-                                                                                                                                   # $VERSION information.
+use Modern::Perl;
 
 package DBIx::Squirrel;
-$DBIx::Squirrel::VERSION = '1.2.3'; # TRIAL
-use warnings;
-use constant E_BAD_ENT_BIND     => 'Cannot associate with an invalid object';
-use constant E_EXP_HASH_ARR_REF => 'Expected a reference to a HASH or ARRAY';
-
+$DBIx::Squirrel::VERSION = '1.2.4'; # TRIAL
 =pod
 
 =encoding UTF-8
@@ -17,7 +12,7 @@ DBIx::Squirrel - A C<DBI> extension
 
 =head1 VERSION
 
-version 1.2.3
+version 1.2.4
 
 =head1 SYNOPSIS
 
@@ -216,158 +211,126 @@ use Exporter;
 use Scalar::Util 'reftype';
 use Sub::Name;
 
-use DBIx::Squirrel::dr ();
-use DBIx::Squirrel::db ();
-use DBIx::Squirrel::st ();
-use DBIx::Squirrel::it ();
-use DBIx::Squirrel::rs ();
-use DBIx::Squirrel::rc ();
-use DBIx::Squirrel::util 'throw';
+use DBIx::Squirrel::dr   ();
+use DBIx::Squirrel::db   ();
+use DBIx::Squirrel::st   ();
+use DBIx::Squirrel::it   ();
+use DBIx::Squirrel::rs   ();
+use DBIx::Squirrel::rc   ();
+use DBIx::Squirrel::util qw/throw uniq/;
+
 
 BEGIN {
-    our @ISA                          = ('DBI');
-    our $FINISH_ACTIVE_BEFORE_EXECUTE = 1;
-    our $NORMALISE_SQL                = 1;
-
-    *NORMALIZE_SQL = *NORMALISE_SQL;
-
-    *connect         = *DBIx::Squirrel::dr::connect;
-    *connect_cached  = *DBIx::Squirrel::dr::connect_cached;
-    *SQL_ABSTRACT    = *DBIx::Squirrel::db::SQL_ABSTRACT;
-    *DEFAULT_SLICE   = *DBIx::Squirrel::it::DEFAULT_SLICE;
-    *DEFAULT_MAXROWS = *DBIx::Squirrel::it::DEFAULT_MAXROWS;
-    *BUF_MULT        = *DBIx::Squirrel::it::BUF_MULT;
-    *BUF_MAXROWS     = *DBIx::Squirrel::it::BUF_MAXROWS;
-
-    *EXPORT_OK   = *DBI::EXPORT_OK;
-    *EXPORT_TAGS = *DBI::EXPORT_TAGS;
-    *err         = *DBI::err;
-    *errstr      = *DBI::errstr;
-    *rows        = *DBI::rows;
-    *lasth       = *DBI::lasth;
-    *state       = *DBI::state;
+    @DBIx::Squirrel::ISA                          = 'DBI';
+    *DBIx::Squirrel::EXPORT_OK                    = *DBI::EXPORT_OK;
+    *DBIx::Squirrel::EXPORT_TAGS                  = *DBI::EXPORT_TAGS;
+    *DBIx::Squirrel::err                          = *DBI::err;
+    *DBIx::Squirrel::errstr                       = *DBI::errstr;
+    *DBIx::Squirrel::rows                         = *DBI::rows;
+    *DBIx::Squirrel::lasth                        = *DBI::lasth;
+    *DBIx::Squirrel::state                        = *DBI::state;
+    *DBIx::Squirrel::connect                      = *DBIx::Squirrel::dr::connect;
+    *DBIx::Squirrel::connect_cached               = *DBIx::Squirrel::dr::connect_cached;
+    *DBIx::Squirrel::SQL_ABSTRACT                 = *DBIx::Squirrel::db::SQL_ABSTRACT;
+    *DBIx::Squirrel::DEFAULT_SLICE                = *DBIx::Squirrel::it::DEFAULT_SLICE;
+    *DBIx::Squirrel::DEFAULT_MAXROWS              = *DBIx::Squirrel::it::DEFAULT_MAXROWS;
+    *DBIx::Squirrel::BUF_MULT                     = *DBIx::Squirrel::it::BUF_MULT;
+    *DBIx::Squirrel::BUF_MAXROWS                  = *DBIx::Squirrel::it::BUF_MAXROWS;
+    $DBIx::Squirrel::FINISH_ACTIVE_BEFORE_EXECUTE = 1;
+    $DBIx::Squirrel::NORMALISE_SQL                = 1;
+    *DBIx::Squirrel::NORMALIZE_SQL                = *DBIx::Squirrel::NORMALISE_SQL;
 }
 
-sub import {
-    my $class  = shift;
-    my $caller = caller;
+use constant E_BAD_ENT_BIND     => 'Cannot associate with an invalid object';
+use constant E_EXP_HASH_ARR_REF => 'Expected a reference to a HASH or ARRAY';
 
-    # Partition import list into lists of helper function names and
-    # DBI imports.
-
-    my ( @helpers, @dbi_imports );
 
+sub _partition_imports_into_helpers_and_dbi_imports {
+    my $class = shift;
+    my(@helpers, @dbi);
     while (@_) {
-        if ( $_[0] =~ m/^database_objects?$/i ) {
-            shift;
-
-            if (@_) {
-                if ( defined $_[0] ) {
-                    if ( ref $_[0] ) {
-                        if ( reftype( $_[0] ) eq 'ARRAY' ) {
-                            push @helpers, @{ +shift };
-                        }
-                    } else {
-                        push @helpers, shift;
-                    }
-                }
+        my $symbol = shift;
+        next unless defined($symbol);
+        if ($symbol eq 'database_objects') {
+            my $symbols = shift;
+            if (UNIVERSAL::isa($symbols, 'ARRAY')) {
+                push @helpers, @{$symbols};
             }
-        } else {
-            push @dbi_imports, shift;
+        }
+        elsif ($symbol eq 'database_object') {
+            $symbol = shift;
+            if (defined($symbol) and not ref($symbol)) {
+                push @helpers, $symbol;
+            }
+        }
+        else {
+            push @dbi, $symbol;
         }
     }
+    return (\@helpers, \@dbi);
+}
 
-    my %seen;
-    @helpers = grep { !$seen{$_}++ } @helpers;
 
-    # Create (if necessary) and export helpers.
-
-    for my $name (@helpers) {
+sub import {
+    no strict 'refs';    ## no critic
+    my $class  = shift;
+    my $caller = caller;
+    my($helpers, $dbi) = $class->_partition_imports_into_helpers_and_dbi_imports(@_);
+    for my $name (@{$helpers}) {
         my $symbol = $class . '::' . $name;
         my $helper = sub {
-
-            # First time the helper receives a value then it is assumed to be
-            # the reference to the associated database object.
-
-            unless ( defined ${$symbol} ) {
+            unless (defined ${$symbol}) {
                 if (@_) {
-                    if (   UNIVERSAL::isa( $_[0], 'DBI::db' )
-                        or UNIVERSAL::isa( $_[0], 'DBI::st' )
-                        or UNIVERSAL::isa( $_[0], 'DBIx::Squirrel::it' ) )
-                    {
-                        ${$symbol} = shift;
-                        return ${$symbol};
-                    }
-
-                    throw E_BAD_ENT_BIND;
+                    throw E_BAD_ENT_BIND
+                      unless UNIVERSAL::isa($_[0], 'DBI::db')
+                      or UNIVERSAL::isa($_[0], 'DBI::st')
+                      or UNIVERSAL::isa($_[0], 'DBIx::Squirrel::it');
+                    ${$symbol} = shift;
+                    return ${$symbol};
                 }
             }
-
-            # At this point, return nothing if no association is defined.
-
             return unless defined ${$symbol};
-
-            # At this point, we have an association. If we have arguments then
-            # we are addressing the associated database object, and they are
-            # passed to the object's relevant method for processing.
-
             if (@_) {
                 my @params = do {
-                    if ( @_ == 1 && ref $_[0] ) {
-                        if ( reftype( $_[0] ) eq 'ARRAY' ) {
-                            @{ +shift };
-                        } elsif ( reftype( $_[0] ) eq 'HASH' ) {
-                            %{ +shift };
-                        } else {
+                    if (@_ == 1 && ref $_[0]) {
+                        if (reftype($_[0]) eq 'ARRAY') {
+                            @{+shift};
+                        }
+                        elsif (reftype($_[0]) eq 'HASH') {
+                            %{+shift};
+                        }
+                        else {
                             throw E_EXP_HASH_ARR_REF;
                         }
-                    } else {
+                    }
+                    else {
                         @_;
                     }
                 };
-
-                if ( UNIVERSAL::isa( ${$symbol}, 'DBI::db' ) ) {
+                if (UNIVERSAL::isa(${$symbol}, 'DBI::db')) {
                     return ${$symbol}->prepare(@params);
-                } elsif ( UNIVERSAL::isa( ${$symbol}, 'DBI::st' ) ) {
+                }
+                elsif (UNIVERSAL::isa(${$symbol}, 'DBI::st')) {
                     return ${$symbol}->execute(@params);
-                } elsif ( UNIVERSAL::isa( ${$symbol}, 'DBIx::Squirrel::it' ) ) {
+                }
+                elsif (UNIVERSAL::isa(${$symbol}, 'DBIx::Squirrel::it')) {
                     return ${$symbol}->iterate(@params);
                 }
+                else {
+                    # ok - no worries
+                }
             }
-
-            # At this point, return the reference to the associated database
-            # object.
-
             return ${$symbol};
         };
-
-        *{$symbol} = subname( $name => $helper );
-
-        # Export any relevant symbols to caller's namespace.
-
-        unless ( defined &{ $caller . '::' . $name } ) {
-            *{ $caller . '::' . $name } = \&{$symbol};
-        }
+        *{$symbol} = subname($name => $helper);
+        *{$caller . '::' . $name} = subname($caller . '::' . $name => \&{$symbol})
+          unless defined &{$caller . '::' . $name};
     }
-
-    # If the caller tried to import any of DBI's exports then take care
-    # of that, otherwise just return our class name.
-
-    if (@dbi_imports) {
-
-        # First import them here.
-
-        DBI->import(@dbi_imports);
-
-        # Then export them to the caller!
-
-        @_ = ( 'DBIx::Squirrel', @dbi_imports );
-
-        # Jump-jump, sugar lump, we don't want a new stack frame!
-
+    if (@{$dbi}) {
+        DBI->import(@{$dbi});
+        @_ = ('DBIx::Squirrel', @{$dbi});
         goto &Exporter::import;
     }
-
     return $class;
 }
 
